<?php /* _\|/_              vim: set et ts=4 sw=4 sts=4 nowrap fdm=marker:
         (o o)                         
+-----oOO-{_}-OOo--------------------------------------------------------+
| ConPresso - Foolproof Content Management                               |
+------------------------------------------------------------------------+
| Copyright (c) Bartels Schoene GmbH & Co. KG, 48149 Muenster, Germany   |
+------------------------------------------------------------------------+
| This source file is subject to ConPresso license version 2002-11-16    |
| that is bundled with this package in the files LICENSE_EN.TXT or       |
| LICENSE_DE.TXT, and is available through the world-wide-web at         |
|     http://www.conpresso.de/license/LICENSE_EN-2002-11-16.TXT or       |
|     http://www.conpresso.de/license/LICENSE_DE-2002-11-16.TXT          |
|                                                                        |
| If you did not receive a copy of the ConPresso license and are unable  |
| to obtain it through the world-wide-web, please send a note to         |
| <license@conpresso.de> so we can e-mail you a copy immediately.        |
+------------------------------------------------------------------------+
| Authors: ConPresso development and support team <support@conpresso.de> |
+------------------------------------------------------------------------+
  $Id$ */
define('CPO', true);
require_once('../_include/checkaccess.inc.php');

$zugang = 0; // FIXME disallow connect for normal users?
require(CPO_BASEDIR.'_include/check.php');

if (isset($_POST['go-export'])) {
    if (!$antiCSRF->checkToken('go-export')) {
        $message[] = ___('Security check failed. Please try again.');
        logaction('export', 'CSRF check failed.');
    } else {
        require(CPO_BASEDIR.'_include/export.inc.php');
        return;
    }
}

require(CPO_BASEDIR.'_include/header.php');

printPageHeader(
    __('Export / import'),
    __('In this view you can ex- or import your database.'),
    'system-exportimport.html#system-exportimport'
);

if (isset($_POST['go-import']) && $_FILES['importfile']['name']!='') {
    if (!$antiCSRF->checkToken('go-import')) {
        $message[] = ___('Security check failed. Please try again.');
        logaction('import', 'CSRF check failed.');
    } else {
        if ($_FILES['importfile']['size']) {

            // upload ok
            $path = CPO_BASEDIR.'_data/';
            $filename = tempnam($path, 'import');

            // move the uploaded file to the new place
            if (!@move_uploaded_file($_FILES['importfile']['tmp_name'], $filename)) {
                $message[] = sprintf(__('<b>ERROR:</b> Make sure the webserver has write-access to the directory %s.'),
                    '<em>'._htmlspecialchars(dirname($filename)).'</em>');
                include(CPO_BASEDIR.'_include/message.php');
                return;
            }
            @chmod($filename, 0666);

            require(CPO_BASEDIR.'_include/import.inc.php');

            @unlink($filename);
            return;
        } 

        $uploadErrors = array(
            __('File was successfully uploaded.'),                      // File successfully uploaded.
            __('The uploaded file exceeded the allowed size.'),         // Uploaded file exceeds the allowed size.
            __('The uploaded file exceeded the allowed size.'),         // Uploaded file exceeds the allowed size.
            __('The file was not uploaded completely. Please try again.'), // File was only partially uploaded, please try again.
            __('No file was received. Please try again.')
        );        // No file was received. Upload again.

        if (isset($_FILES['importfile']['error'])) // this exists since PHP 4.2
            $error = $uploadErrors[$_FILES['importfile']['error']];
        else $error = __('Unknown error - Please check if the size of the file exceeds the maximum uploadable file size.');

        $message[] = sprintf(__('There was an error: %s').'<br />', $error);
    }
}
if (isset($_POST['go-import']) && $_FILES['importfile']['name']=='') {
    $message[] = ___('Please specify an import file.');
}
include(CPO_BASEDIR.'_include/message.php');

?>

<table class="colored" style="width: 100%">
<form method="post" action="<?php echo $_SERVER['PHP_SELF']; ?>">
    <?php $antiCSRF->printInput('go-export', false); ?>
<thead><tr>
    <th colspan="2"><span><?php echo __('Export'); ?></span></th>
</tr></thead><tbody>
<tr>
    <td class="leftrow"><?php echo __('Filename:') ?></td>
    <td class="rightrow">
        <input type="text" name="filename" value="cpo_export-<?php echo date('Ymd'); ?>.xml" size="40" />
    </td>
</tr><tr>
    <td>&nbsp;</td>
    <td>
        <input type="submit" class="button" name="go-export" value="<?php echo __('export file'); ?>" />
        <?php echo help('system-exportimport.html#system-exportimport-export'); ?><br /><br />
        <?php echo '<img src="'.SKIN_URL.'sym_note.gif" style="vertical-align: text-bottom;" alt="'.__('Note').'" title="'.__('Note').'"> '; ?>
        <?php echo __('If you press <em>export file</em>, an XML-file with a size of several MB or bigger will be sent to you.'); ?>
    </td>
</tr>
</form>
</tbody></table>

<table class="colored" style="width: 100%">
<form method="post" action="<?php echo $_SERVER['PHP_SELF']; ?>" enctype="multipart/form-data">
<?php $antiCSRF->printInput('go-import', false); ?>
<thead><tr>
    <th colspan="2"><span><?php echo __('Import'); ?></span></th>
</tr></thead><tbody><tr>
    <td class="leftrow"><?php echo __('Filename:'); ?></td>
    <td class="rightrow">
        <input type="file" name="importfile" value="" size="40"/>
    </td>
</tr><tr>
    <td>&nbsp;</td>
    <td>
        <input type="submit" class="button" name="go-import" value="<?php echo ___('import file'); ?>" />
        <?php echo help('system-exportimport.html#system-exportimport-import'); ?><br /><br />
        <?php echo '<img src="'.SKIN_URL.'sym_warning.gif" style="vertical-align: text-bottom;" alt="'.__('Warning').'" title="'.__('Warning').'"> '; ?>
        <?php echo __('If you press <em>import file</em>, the chosen XML file will be uploaded and <b>all existing data will be overriden</b>!'); ?>
    </td>
</tr>
</form>
</tbody></table>

<?php require(CPO_BASEDIR.'_include/footer.php');