<?php /* _\|/_              vim: set et ts=4 sw=4 sts=4 nowrap fdm=marker:
         (o o)                         
+-----oOO-{_}-OOo--------------------------------------------------------+
| ConPresso - Foolproof Content Management                               |
+------------------------------------------------------------------------+
| Copyright (c) Bartels Schoene GmbH & Co. KG, 48149 Muenster, Germany   |
+------------------------------------------------------------------------+
| This source file is subject to ConPresso license version 2002-11-16    |
| that is bundled with this package in the files LICENSE_EN.TXT or       |
| LICENSE_DE.TXT, and is available through the world-wide-web at         |
|     http://www.conpresso.de/license/LICENSE_EN-2002-11-16.TXT or       |
|     http://www.conpresso.de/license/LICENSE_DE-2002-11-16.TXT          |
|                                                                        |
| If you did not receive a copy of the ConPresso license and are unable  |
| to obtain it through the world-wide-web, please send a note to         |
| <license@conpresso.de> so we can e-mail you a copy immediately.        |
+------------------------------------------------------------------------+
| Authors: ConPresso development and support team <support@conpresso.de> |
+------------------------------------------------------------------------+
  $Id$ */
if (!defined('CPO')) exit;

$db = new DB;
// fetch all rubrics (needed in the parser to link to other rubrics, etc.)
$query = 'SELECT id, directory, name, seclevel, source_rubric_id, settings '
        .'FROM '.CPO_RUBRIC.' ';
$db->query($query);
while ($db->next_record()) {
    $cpoRubrics[$db->v('id')] = array(
        'id'               => $db->v('id'),
        'directory'        => $db->v('directory'),
        'name'             => $db->v('name'),
        'seclevel'         => $db->v('seclevel'),
        'source_rubric_id' => $db->v('source_rubric_id'),
        '_settings'        => $db->v('settings')
    );
}

// setup the rubric-settings
foreach ($cpoRubrics as $k=>$v) {
    // start with defaults
    $cpoRubrics[$v['id']]['settings'] = $cpoRubricSettingsDefaults;

    $_original = unserialize($v['_settings']);
    if (!is_array($_original)) continue;

    // use settings from different rubric?
    if ($v['source_rubric_id']>0) {
        $_source  = $cpoRubricSettingsDefaults;
        $__source = unserialize($cpoRubrics[$v['source_rubric_id']]['_settings']);

        if (is_array($__source)) 
            foreach ($__source as $k2=>$v2) $_source[$k2] = $v2;
    }

    foreach ($cpoRubrics[$v['id']]['settings'] as $k2=>$v2) {
        // use original settings;
        if (isset($_original[$k2]))
            $cpoRubrics[$v['id']]['settings'][$k2] = $_original[$k2];

        // use settings from different rubric
        if ($v['source_rubric_id']>0 && 
            $k2!='title' &&
            $k2!='disableRubric' &&
            $k2!='disableRubricText' &&
            $k2!='metaKeywords' &&
            $k2!='metaDescription') {

            $cpoRubrics[$v['id']]['settings'][$k2] = $_source[$k2];
        }
    }

    // if no date_format is set, use the system date_format as default
    if (empty($cpoRubrics[$v['id']]['settings']['date_format'])) {
        $cpoRubrics[$v['id']]['settings']['date_format'] = $cpoSystem['date_format'];
    }
}

// figure out actual rubric

// use PATH_INFO to fetch rubric name and article id
if ($cpoSystem['PATH_INFO'] && isset($_SERVER['PATH_INFO'])) {
    $directory = basename(dirname(substr($_SERVER['PHP_SELF'], 0, -strlen($_SERVER['PATH_INFO'])))); 

    preg_match('=/([^/]*)(/([0-9]*))?=', $_SERVER['PATH_INFO'], $matches);
    $_REQUEST['rubric'] = $matches[1];

    if (isset($matches[3])) {
        $_REQUEST['nr'] = $matches[3]; // FIXME having to set alle three really sucks :-(
        $_POST['nr']    = $matches[3];
        $_GET['nr']     = $matches[3];
    }
}

$cpoRubricId = 0;
if (isset($cpoRubric['id'])) $cpoRubricId = $cpoRubric['id']; // needed for backend files including this one

// make it possible to specify the rubric using $_REQUEST['rubric']
if (isset($_REQUEST['rubric'])) {
    if (preg_match('/^([0-9]+)$/', $_REQUEST['rubric'])) {
        // specified rubric is an id
        $cpoRubricId = $_REQUEST['rubric'];
    } else {
        // specified rubric is a name 
        foreach ($cpoRubrics as $k=>$v) {
            if (strtolower($v['name'])!=strtolower($_REQUEST['rubric'])) continue;

            $cpoRubricId = $v['id'];
            break;
        }
    }
}

// if we found no rubric yet, search the rubric based on the directory name
// or just use the first one found
if ($cpoRubricId==0) {
    $firstrubric = false;
    foreach ($cpoRubrics as $k=>$v) {
        if (strtolower($v['name'])!=strtolower($directory) &&
            strtolower($v['directory'])!=strtolower($directory)) continue;

        if (!$firstrubric) {
            // if no name equaled directory choose first rubric from the database 
            // (where the directory fits)
            $firstrubric = true;
            $cpoRubricId = $v['id'];
        }

        if (strtolower($v['name'])!=strtolower($directory)) continue;

        // Found rubric where name equals directory...
        $cpoRubricId = $v['id'];
        break;
    }
}

// maintain backward compatibility
$cpoRubric = $cpoRubrics[$cpoRubricId];
$cpoRubricSettings = $cpoRubrics[$cpoRubricId]['settings'];

$tl['Found:']        = $cpoRubricSettings['pager_found'];
$tl['Results:']      = $cpoRubricSettings['pager_results'];
$tl['previous page'] = $cpoRubricSettings['pager_previous'];
$tl['next page']     = $cpoRubricSettings['pager_next'];