<?php /* _\|/_              vim: set et ts=4 sw=4 sts=4 nowrap fdm=marker:
         (o o)                         
+-----oOO-{_}-OOo--------------------------------------------------------+
| ConPresso - Foolproof Content Management                               |
+------------------------------------------------------------------------+
| Copyright (c) Bartels Schoene GmbH & Co. KG, 48149 Muenster, Germany   |
+------------------------------------------------------------------------+
| This source file is subject to ConPresso license version 2002-11-16    |
| that is bundled with this package in the files LICENSE_EN.TXT or       |
| LICENSE_DE.TXT, and is available through the world-wide-web at         |
|     http://www.conpresso.de/license/LICENSE_EN-2002-11-16.TXT or       |
|     http://www.conpresso.de/license/LICENSE_DE-2002-11-16.TXT          |
|                                                                        |
| If you did not receive a copy of the ConPresso license and are unable  |
| to obtain it through the world-wide-web, please send a note to         |
| <license@conpresso.de> so we can e-mail you a copy immediately.        |
+------------------------------------------------------------------------+
| Authors: ConPresso development and support team <support@conpresso.de> |
+------------------------------------------------------------------------+
  $Id$ */
define('CPO', true);
define('SETUP', true);
require_once('../_include/common.inc.php');

$errors = array();
$message = array();
if (!isset($_POST['email'])) $_POST['email'] = '';

switch($_POST['action']) {
case 'send test mail':
    if (empty($_POST['email'])) {
        $message[] = ___('Please specify an e-mail address to test sending of e-mails!').'<br />';
    } else {
        mail($_POST['email'], sprintf('[%s] Testmail', $CPO['product']),
            sprintf(__('This message was sent while installing %s.'), $CPO['product'])."\n\n"
            .wordwrap(__('If you received it, your server is able to send e-mails.')));
        $message[] = sprintf(___('Sent test e-mail to %s. Please make sure it arrived in the mailbox.').'<br />', $_POST['email']);
        $_SESSION['email'] = $_POST['email'];
    }
    break;
}

$ok  = '<br /><span style="color: #0c0; font-weight: bold;">'.___('Ok,').' </span> ';
$nok = '<br /><span style="color: #f00; font-weight: bold;">'.___('Problem:').' </span> ';
$pok = '<br /><span style="color: #fa0; font-weight: bold;">'.___('Note:').' </span> ';
$sol = '<br /><span style="color: #00f; font-weight: bold;">'.___('Solution:').' </span>';

$notimeout = true;
include(CPO_BASEDIR.'_include/header.php');
?>
<script type="text/javascript">
    parent.cpo_navigation.location.href = "../_admin/frame_navigation.php?s=1&l=<?php echo urlencode($_POST['language']); ?>";
</script>
<?php
printPageHeader(
    ___('Step 1/3 - Check requirements'),
    sprintf(___('The setup will now check if all requirements to run %s are fullfilled. These are usually PHP settings or access rights to directories. If it lists any Problems, please try to fix them as described.'), _htmlspecialchars($CPO['product'])),
    'setup-setupcall.html#setup-step1',
    false, '', $_POST['language']
);


if (@file_exists(CPO_BASEDIR.'_cfg/db.inc.php')) {
    $message[] = sprintf(___('Setup was already run for this project. To start over delete the file %s and remove all related tables from the database.'), '<em>_cfg/db.inc.php</em>');
    include(CPO_BASEDIR.'_include/message.php');
    exit;
}

include(CPO_BASEDIR.'_include/message.php');


echo '<table class="colored" style="width: 100%">';
echo '<thead><tr><th colspan="2"><span>'.___('Requirements').'</span></th></tr></thead>';
echo '<tbody>';
print('<tr><td class="leftrow">'.___('PHP version').'</td><td class="rightrow">');
print(sprintf(___('%s needs at minimum PHP version 4.1.2.'), _htmlspecialchars($CPO['product'])));
if (!function_exists('version_compare')){ 
    printf($nok.sprintf(___('The setup can not check your PHP version because of a missing version_compare() function. This usually is a sign for an older PHP version that is not ready to run %s. PHP returns a version of %s.'), 
        _htmlspecialchars($CPO['product'])),
        phpversion()
    );
    $errors['version'] = print(___('Please upgrade your PHP to at least version 4.1.2.'));
    print($sol.$errors['version']);
} else {
    if (version_compare(phpversion(), '4.1.2')<0) {
        printf($nok.sprintf(___('Your PHP Version is %s, which is too old and not ready to run %s.'), 
            phpversion(),
            _htmlspecialchars($CPO['product']))
        );
        $errors['version'] = print(___('Please upgrade your PHP to at least version 4.1.2.'));
        print($sol.$errors['version']);
    } else {
        printf($ok.sprintf(___('your PHP Version is %s, which is enough to satisfy the requirements of %s.'), 
            phpversion(),
            _htmlspecialchars($CPO['product']))
        );
    }
}
print('</td></tr>');

print('<tr><td>'.___('MySQL support').'</td><td class="rightrow">');
print(sprintf(___('%s needs PHP to support connections to the MySQL database.'), _htmlspecialchars($CPO['product'])));
if (!function_exists('mysql_connect')) {
    print($nok.___('PHP does not support the function mysql_connect().'));
    $errors['mysql'] = ___('Please make sure your PHP does support MySQL functions. To do so you have to install the PHP MySQL module or recompile PHP with the correct parameters.');
    print($sol.$errors['mysql']);
} else {
    print($ok.___('your PHP supports MySQL functions.'));
}
print('</td></tr>');

print('<tr><td>'.___('Write access to _data').'</td><td class="rightrow">');
print(sprintf(___('%s needs write access on the _data directory to store uploaded files and images.'), _htmlspecialchars($CPO['product'])));
if (!is_writeable(CPO_BASEDIR.'_data')) { // FIXME check if the directory exists.
    print($nok.___('The _data directory is not writeable.'));
    $errors['_data'] = ___('Please make sure that the user your webserver is running as has write access to the _data directory. Usually you can use your FTP client or command line tools to do so.');
    print($sol.$errors['_data']);
} else {
    print($ok.___('the _data directory is writeable.'));
}
print('</td></tr>');

// file integrity check
print('<tr><td>'.___('File integrity').'</td><td class="rightrow">');
print(___('This check makes sure that all needed directories and files were transferred correctly to the server.'));

$noIntregrityCheck = false;
$integrity = array(); $md5_files = array();
if (!is_readable(CPO_BASEDIR.'_include/md5_files.inc.php')) $integrity[] = '_include/md5_files.inc.php';
else {
    include_once(CPO_BASEDIR.'_include/md5_files.inc.php');
    foreach ($md5_files as $k=>$v) {
            if ($k=='') continue;
            if ($k=='off' && $v=='off') {
                $noIntregrityCheck = true;
                break;
            }
            if (is_dir(CPO_BASEDIR.$k)) continue;
            if (!is_readable(CPO_BASEDIR.$k)) {
                $integrity[] = $k;
                continue;
            }
            $buffer = '';
            $handle = fopen (CPO_BASEDIR.$k, 'rb');
            $buffer = fread($handle, filesize(CPO_BASEDIR.$k));
            fclose ($handle);

            if ($v==md5($buffer)) continue;
            $integrity[] = $k;
            if (count($integrity)>=10) break;
    }
}
if (count($integrity)>0) {
    print($nok.___('Looks like some files or directories were not transferred correctly:').'<br />');
    $comma = ' ';
    foreach ($integrity as $v) {
        print($comma.$v);
        $comma = ', ';
    }
    if (count($integrity)>=10) print($comma.'...');
    $errors['integrity'] = ___('Please make sure that all files and directories are transferred to the server as they were included in the distributed archive. Also make sure that the directory structure stays the same.');
    print($sol.$errors['integrity']);
} else {
    if ($noIntregrityCheck) {
        print($pok.___('The file and directory integrity check was skipped.'));
    } else {
        print($ok.___('the file and directory integrity check did not find any problems.'));
    }
}
print('</td></tr>');
print('</tbody></table>');

print(''.___('Some settings are not required, but allow special features or make the life of the administrator easier. Those are checked now.').'<br /><br /><br />');

echo '<table class="colored" style="width: 100%">';
echo '<thead><tr><th colspan="2"><span>'.___('Optional settings').'</span></th></tr></thead>';
echo '<tbody>';
print('<tr><td class="leftrow">'.__('Write access to _cfg').'</td><td class="rightrow">');
print(sprintf(___('%s needs write access on the _cfg directory to create the database config file in step two. You can create the file manually, but to avoid errors you might want to allow %s to create that file automatically.'), _htmlspecialchars($CPO['product']), _htmlspecialchars($CPO['product'])));
if (!is_writeable(CPO_BASEDIR.'_cfg')) { // FIXME check if the directory exists.
    print($pok);
    print(sprintf(___('The _cfg directory is not writeable. If you want %s to create the database configuration in step two automatically, please allow write access to this directory.'), _htmlspecialchars($CPO['product'])));
} else {
    print($pok);
    print(___('The _cfg directory is writeable. You might want to remove the write access to the _cfg directory after the setup has finished.'));
}
print('</td></tr>');

print('<tr><td>'.___('Transparent session ID support').'</td><td class="rightrow">');
print(sprintf(___('The transparent SID support of PHP is not required for %s.  But it is needed as a fallback if cookie based sessions don\'t work, because they are disabled in clients, etc. If it is disabled those clients will not be able to log in as editors or as readers of personalized or closed rubrics. If it is enabled PHP will automatically use URL based sessions.'), _htmlspecialchars($CPO['product'])).' ');
print(___('Please note that URL based session management might add security risks. Users may send a URL containing active session IDs to their friends by e-mail or similar.'));
if (!(bool)ini_get('session.use_trans_sid')) {
    print($pok);
    print(___('Transparent session ID support is disabled on this server.'));
} else {
    print($pok);
    print(___('Transparent session ID support is enabled on this server.'));
}
print('</td></tr>');

print('<tr><td>'.___('Send e-mail').'</td><td class="rightrow">');
printf(sprintf(___('%s sends e-mail as notifications if it is configured to do so. The setup routine can not check if an e-mail really gets send, but the following form gives you a chance to test it for yourself. Please fill in an e-mail-address end press %s if you want to test this.'), _htmlspecialchars($CPO['product']), '<em>'.___('send test e-mail').'</em>')); 
print('<br /><br />');
printf('<form method="post" action="%s">', _htmlspecialchars($_SERVER['PHP_SELF']));
printf('<input type="hidden" name="language" value="%s">', _htmlspecialchars($_POST['language']));
print('<input type="hidden" name="action" value="send test mail">');
printf('<input type="text" class="text" name="email" value="%s" />&nbsp;', _htmlspecialchars($_POST['$email']));
printf('<input type="submit" class="button" value="%s">', ___('send test e-mail'));
print('</form>');
print('</td></tr>');
print('</tbody></table>');

print('<h1>'.___('Summary').'</h1>');
if (count($errors)>0) {
    print(sprintf(___('Some problems were discovered while checking the requirements for %s. Before you can go on, fix the following problems:'), _htmlspecialchars($CPO['product'])));
    print('<ul>');
    foreach ($errors as $v) print('<li>'.$v.'</li>');
    print('</ul>');

    print('<form method="post" action="step1.php">');
    printf('<input type="hidden" name="language" value="%s">', _htmlspecialchars($_POST['language']));
    printf('<input type="submit" class="button" value="%s">', ___('retry'));
    print('</form>');
} else {
    print(sprintf(___('Your server meets the %s requirements. You can go on to '), _htmlspecialchars($CPO['product'])));
    print('<form style="display: inline;" method="post" action="step2.php">');
    printf('<input type="hidden" name="language" value="%s">', _htmlspecialchars($_POST['language']));
    printf('<input type="hidden" name="email" value="%s">', _htmlspecialchars($_POST['email']));
    printf('<input type="submit" class="button" value="%s">', ___('Step 2'));
    print('</form>');
}

echo '<br /><br />';
include(CPO_BASEDIR.'_include/footer.php'); 
?>
